#[non_exhaustive]pub struct RoomSummary {
pub room_id: OwnedRoomId,
pub canonical_alias: Option<OwnedRoomAliasId>,
pub name: Option<String>,
pub topic: Option<String>,
pub avatar_url: Option<OwnedMxcUri>,
pub room_type: Option<RoomType>,
pub num_joined_members: UInt,
pub join_rule: JoinRuleSummary,
pub world_readable: bool,
pub guest_can_join: bool,
pub encryption: Option<EventEncryptionAlgorithm>,
pub room_version: Option<RoomVersionId>,
}Expand description
The summary of a room’s state.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.room_id: OwnedRoomIdThe ID of the room.
canonical_alias: Option<OwnedRoomAliasId>The canonical alias of the room, if any.
If the compat-empty-string-null cargo feature is enabled, this field being an empty
string in JSON will result in None here during deserialization.
name: Option<String>The name of the room, if any.
topic: Option<String>The topic of the room, if any.
avatar_url: Option<OwnedMxcUri>The URL for the room’s avatar, if one is set.
If you activate the compat-empty-string-null feature, this field being an empty string in
JSON will result in None here during deserialization.
room_type: Option<RoomType>The type of room from m.room.create, if any.
num_joined_members: UIntThe number of members joined to the room.
join_rule: JoinRuleSummaryThe join rule of the room.
world_readable: boolWhether the room may be viewed by users without joining.
guest_can_join: boolWhether guest users may join the room and participate in it.
If they can, they will be subject to ordinary power level rules like any other user.
encryption: Option<EventEncryptionAlgorithm>If the room is encrypted, the algorithm used for this room.
room_version: Option<RoomVersionId>The version of the room.
Implementations
Sourceimpl RoomSummary
impl RoomSummary
Sourcepub fn new(
room_id: OwnedRoomId,
join_rule: JoinRuleSummary,
guest_can_join: bool,
num_joined_members: UInt,
world_readable: bool,
) -> RoomSummary
Available on crate feature events only.
pub fn new( room_id: OwnedRoomId, join_rule: JoinRuleSummary, guest_can_join: bool, num_joined_members: UInt, world_readable: bool, ) -> RoomSummary
events only.Construct a new RoomSummary with the given required fields.